package main

import (
	"fmt"
	"io/ioutil"
	"net/http"
)

func uploadGo(w http.ResponseWriter, r *http.Request) {
	if r.Method != "POST" {
		return
	}

	err := r.ParseForm()
	if err != nil {
		http.Error(w, "Request parameters not parsed", 500)
		return
	}
	err = r.ParseMultipartForm(5 << 20)
	if err != nil {
		http.Error(w, "Request parameters not parsed", 500)
		return
	}

	project := r.Form.Get("project")
	tag := r.Form.Get("tag")
	id := r.Form.Get("id")

	if project == "" || tag == "" || id == "" {
		http.Error(w, "Request parameters [secret, project, tag, id] not found", 400)
		return
	}
	file, _, err := r.FormFile("file")
	if err != nil {
		http.Error(w, "Request parameter file not found", 400)
		return
	}
	b, _ := ioutil.ReadAll(file)
	coverage := parseCoverage(string(b))

	db.Exec("INSERT INTO badge (commit_hash, percentage) VALUES (?, ?)", id, coverage)
	db.Exec("INSERT INTO alias (commit_hash, project_name, project_tag) VALUES (?, ?, ?) ON DUPLICATE KEY UPDATE commit=?", id, project, tag, id)
	w.Header().Set("Content-Type", "application/json")
	fmt.Fprintf(w, `{"success": "true", "coverage": `+toOneDecimal(coverage*100)+`}`)
}
